@@ -20,7 +20,7 @@ from flask_executor.futures import Future
 # lib imports
 from .classes import RunnerParser
 from .helpers import get_logger
-
+from .exceptions import JobNotFoundException, JobStillRunningException
 
 logger = get_logger()
 runner_parser = RunnerParser()
@@ -28,14 +28,28 @@ runner_parser = RunnerParser()
 
 class Shell2HttpAPI(MethodView):
     """
-    Flask.MethodView that registers GET and POST methods for a given endpoint.
-    This is invoked on `Shell2HTTP.register_command`.
-    Internal use only.
+    ``Flask.MethodView`` that creates ``GET``, ``POST`` and ``DELETE``
+    methods for a given endpoint.
+    This is invoked on ``Shell2HTTP.register_command``.
+
+    *Internal use only.*
     """
 
     def get(self):
+        """
+        Get report by job key.
+        Args:
+            key (str):
+                - Future key
+            wait (str):
+                - If ``true``, then wait for future to finish and return result.
+        """
+
+        key: str = ""
+        report: Dict = {}
         try:
-            key: str = request.args.get("key")
+            key = request.args.get("key")
+            wait = request.args.get("wait", "").lower() == "true"
             logger.info(
                 f"Job: '{key}' --> Report requested. "
                 f"Requester: '{request.remote_addr}'."
@@ -46,29 +60,44 @@ class Shell2HttpAPI(MethodView):
             # get the future object
             future: Future = self.executor.futures._futures.get(key)
             if not future:
-                raise Exception(f"No report exists for key: '{key}'.")
+                raise JobNotFoundException(f"No report exists for key: '{key}'.")
 
             # check if job has been finished
-            if not future.done():
-                logger.debug(f"Job: '{key}' --> still running.")
-                return make_response(jsonify(status="running", key=key), 200)
+            if not wait and not future.done():
+                raise JobStillRunningException()
 
             # pop future object since it has been finished
             self.executor.futures.pop(key)
 
             # if yes, get result from store
-            report: Dict = future.result()
+            report = future.result()
             if not report:
-                raise Exception(f"Job: '{key}' --> No report exists.")
+                raise JobNotFoundException(f"Job: '{key}' --> No report exists.")
 
             logger.debug(f"Job: '{key}' --> Requested report: {report}")
             return jsonify(report)
 
-        except Exception as e:
+        except JobNotFoundException as e:
             logger.error(e)
             return make_response(jsonify(error=str(e)), HTTPStatus.NOT_FOUND)
 
+        except JobStillRunningException:
+            logger.debug(f"Job: '{key}' --> still running.")
+            return make_response(
+                jsonify(
+                    status="running",
+                    key=key,
+                    result_url=self.__build_result_url(key),
+                ),
+                HTTPStatus.OK,
+            )
+
+        except Exception as e:
+            logger.error(e)
+            return make_response(jsonify(error=str(e)), HTTPStatus.BAD_REQUEST)
+
     def post(self):
+        key: str = ""
         try:
             logger.info(
                 f"Received request for endpoint: '{request.url_rule}'. "
@@ -96,16 +125,59 @@ class Shell2HttpAPI(MethodView):
                 )
 
             logger.info(f"Job: '{key}' --> added to queue for command: {cmd}")
-            result_url = f"{request.base_url}?key={key}"
+            result_url = self.__build_result_url(key)
             return make_response(
                 jsonify(status="running", key=key, result_url=result_url),
                 HTTPStatus.ACCEPTED,
             )
 
+        except Exception as e:
+            logger.error(e)
+            response_dict = {"error": str(e)}
+            if key:
+                response_dict["key"] = key
+                response_dict["result_url"] = self.__build_result_url(key)
+            return make_response(jsonify(response_dict), HTTPStatus.BAD_REQUEST)
+
+    def delete(self):
+        """
+        Cancel (if running) and delete job by job key.
+        Args:
+            key (str):
+                - Future key
+        """
+        try:
+            key = request.args.get("key")
+            logger.info(
+                f"Job: '{key}' --> deletion requested. "
+                f"Requester: '{request.remote_addr}'."
+            )
+            if not key:
+                raise Exception("No key provided in arguments.")
+
+            # get the future object
+            future: Future = self.executor.futures._futures.get(key)
+            if not future:
+                raise JobNotFoundException(f"No job exists for key: '{key}'.")
+
+            # cancel and delete from memory
+            future.cancel()
+            self.executor.futures.pop(key)
+
+            return make_response({}, HTTPStatus.NO_CONTENT)
+
+        except JobNotFoundException as e:
+            logger.error(e)
+            return make_response(jsonify(error=str(e)), HTTPStatus.NOT_FOUND)
+
         except Exception as e:
             logger.error(e)
             return make_response(jsonify(error=str(e)), HTTPStatus.BAD_REQUEST)
 
+    @classmethod
+    def __build_result_url(cls, key: str) -> str:
+        return f"{request.base_url}?key={key}&wait=false"
+
     def __init__(
         self,
         command_name: str,
